@@ -16,22 +16,24 @@
 #ifndef DLGXMPPCONSOLE_H
 #define DLGXMPPCONSOLE_H
 
+#include <QDialog>
+
 #include "ui_dlgxmppconsole.h"
 
 class JabberClient;
 
-class dlgXMPPConsole : public KDialog
+class dlgXMPPConsole : public QDialog
 {
 	Q_OBJECT
 public:
-	explicit dlgXMPPConsole(JabberClient *client, QWidget *parent = 0);
+	explicit dlgXMPPConsole(JabberClient *client, QWidget *parent = nullptr);
 	virtual ~dlgXMPPConsole();
 
-public slots:
+public Q_SLOTS:
 	void slotIncomingXML(const QString &msg);
 	void slotOutgoingXML(const QString &msg);
 
-private slots:
+private Q_SLOTS:
 	void slotSend();
 	void slotClear();
 
